@@ -3,13 +3,11 @@
 
 from trytond.pool import Pool
 
-from . import stock
-from . import carrier
+from . import carrier, stock
 
 
 def register():
     Pool.register(
-        stock.PackageType,
         stock.Package,
         stock.ShipmentOut,
         stock.ShipmentInReturn,
@@ -17,4 +15,8 @@ def register():
         module='stock_package_shipping', type_='model')
     Pool.register(
         stock.CreateShipping,
+        stock.PrintShippingLabel,
         module='stock_package_shipping', type_='wizard')
+    Pool.register(
+        stock.ShippingLabel,
+        module='stock_package_shipping', type_='report')
